/**
 * $Id: JamonMonitorFactory.java,v 1.2 2008/12/27 17:31:06 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 27.12.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.monitor;

import com.jamonapi.*;

/**
 * This is a thin wrapper around com.jamonapi.MonitorFactory to keep the
 * ProfileStatistic class clean from com.jamonapi dependencies.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 27.12.2008
 * @version $Revision: 1.2 $
 */
public class JamonMonitorFactory {
    
    public static void reset() {
        MonitorFactory.reset();
    }
    
    public static ProfileMonitor start(String label) {
        Monitor mon = MonitorFactory.start(label);
        return new JamonMonitor(mon);
    }
    
    public static ProfileMonitor[] getMonitors() {
        MonitorComposite rootMonitor = MonitorFactory.getRootMonitor();
        Monitor[] monitors = rootMonitor.getMonitors();
        ProfileMonitor[] profMonitors = new JamonMonitor[monitors.length];
        for (int i = 0; i < monitors.length; i++) {
            profMonitors[i] = new JamonMonitor(monitors[i]);
        }
        return profMonitors;
    }

}

/**
 * $Log: JamonMonitorFactory.java,v $
 * Revision 1.2  2008/12/27 17:31:06  oboehm
 * reset() added to MBean interface
 *
 * Revision 1.1  2008/12/27 15:20:11  oboehm
 * ProfileStatistic tested without com.jamonapi in classpath
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/monitor/JamonMonitorFactory.java,v $
 */
