/**
 * $Id: JoinPointHelper.java,v 1.4 2008/12/09 19:28:11 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 23.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.util;

import org.aspectj.lang.*;
import org.aspectj.lang.reflect.FieldSignature;

import patterntesting.runtime.annotation.NullArgsAllowed;

/**
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 23.10.2008
 * @version $Revision: 1.4 $
 */
public class JoinPointHelper {
	
    public static String getAsString(JoinPoint joinpoint) {
        Signature sig = joinpoint.getSignature();
        Object[] args = joinpoint.getArgs();
        if (sig instanceof FieldSignature) {
            if (args.length == 0) {
                return "get " + sig.toShortString();
            } else {
                return "set " + sig.toShortString() + " = "
                        + getArgAsString(args[0]);
            }
        } else {
            return getAsString(sig.getDeclaringTypeName(), sig)
                    + getArgsAsString(args);
        }
    }
    
    public static String getAsShortString(JoinPoint joinpoint) {
        Signature sig = joinpoint.getSignature();
        if (sig instanceof FieldSignature) {
            return getAsString(joinpoint);
        }
        Object[] args = joinpoint.getArgs();
        return getAsString(sig.getDeclaringType().getSimpleName(), sig)
                    + getArgsAsString(args);
    }
    
    private static String getAsString(String type, Signature sig) {
        String name = sig.getName();
        if (name.equals("<init>")) {
            return "new " + type;
        } else {
            return type + "." + name;
        }
    }

	@NullArgsAllowed
    public static String getArgsAsString(final Object[] args) {
        if ((args == null) || (args.length == 0)) {
            return "()";
        }
        String s = "(" + getArgAsString(args[0]);
        for (int i = 1; i < args.length; i++) {
            s += ", " + getArgAsString(args[i]);
        }
        return s + ")";
    }
	
    @NullArgsAllowed
    public static String getArgAsString(final Object obj) {
    	if (obj == null) {
    		return "(null)";
    	}
    	if (obj instanceof String) {
    		return "\"" + obj + "\"";
    	}
    	return obj.toString();
    }

}

/**
 * $Log: JoinPointHelper.java,v $
 * Revision 1.4  2008/12/09 19:28:11  oboehm
 * NotNull annotation is now available during runtime
 * logo for banner right created
 *
 * Revision 1.3  2008/12/07 21:12:57  oboehm
 * "<init>" is now shown als "new"
 *
 * Revision 1.2  2008/12/07 13:53:38  oboehm
 * refactorings and minor reorganisations
 *
 * Revision 1.1  2008/12/01 21:38:12  oboehm
 * some reorganisation
 * warning is now printed for @Synchronized methods
 * (without @Synchronized class)
 *
 * Revision 1.1  2008/10/23 20:24:09  oboehm
 * improved logging output
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/util/JoinPointHelper.java,v $
 */
